plotData <- function(path=NA){
  if (is.na(path))stop("Path to data is missing")
  
  ### read data
  train_humidity <- readRDS(paste(path,"train_humidity.RDS",sep="/", collapse=NULL));
  train_temperature <- readRDS(paste(path,"train_temperature.RDS",sep="/", collapse=NULL));
  train_weather <- readRDS(paste(path,"train_weather.RDS",sep="/", collapse=NULL));
  
  ### add column with data type indicator
  temptrain <- data.frame(train_temperature$datetime,train_temperature$value,"temperature");
  humiditytrain <- data.frame(train_humidity$datetime,train_humidity$value,"humidity");
  weathertrain <- data.frame(train_weather, "ambient temperature");
  
  ### set consistent col.names
  colnames(temptrain) <- c("datetime", "value", "DataType");
  colnames(humiditytrain) <- c("datetime", "value", "DataType");
  colnames(weathertrain) <- c("datetime", "value", "DataType");

  ### merge series to one single data.frame
  mergedData <- rbind(temptrain, humiditytrain, weathertrain);
  mergedData <- mergedData[order(mergedData[,1]),]; 

  ### plot it
  ggplot(mergedData, aes(x=datetime)) +    
    geom_line(aes(y = value, group = DataType, colour=DataType)) +
    geom_point(aes(y = value, colour=DataType),size=1) +
    scale_colour_manual(values = c("#009966", "#0033CC", "#FF3399")) + # Tuerkis / Tuerkis / Blau / Blau / Magenta
    scale_x_datetime(breaks = date_breaks("1 day") 
                   , labels = date_format("%d/%m")) + 
    xlab("") +
    ylab("") +
    theme(legend.position="top"
          , legend.direction="horizontal"
          , legend.title = element_blank()) +    
    theme_bw()
}